@@ -1,4 +1,5 @@
 import inspect
+import logging
 
 from PyQt5.QtCore import QObject
 
@@ -7,6 +8,8 @@ class ManagerBase(QObject):
     def __init__(self, context, **kwargs):
         super().__init__(**kwargs)
 
+        self._log = logging.getLogger(self.__class__.__name__)
+
         self._ctx = context
 
     def eventFilter(self, event_object, event) -> bool:
